/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

import { vi } from 'vitest';
import { createChainedFunction } from '@instructure/ui-utils';
import { render, screen } from '@testing-library/react';
import '@testing-library/jest-dom';
import { safeCloneElement } from '../safeCloneElement';
import { jsx as _jsx } from "@emotion/react/jsx-runtime";
describe('safeCloneElement', () => {
  const SafeClone = function ({
    element,
    props,
    children
  }) {
    return safeCloneElement(element, props, children);
  };
  it('should preserve refs', () => {
    const origRef = vi.fn();
    const cloneRef = vi.fn();
    render(_jsx(SafeClone, {
      element: _jsx("div", {
        ref: origRef
      }),
      props: {
        ref: cloneRef
      }
    }));
    expect(origRef).toHaveBeenCalled();
    expect(cloneRef).toHaveBeenCalled();
  });
  it('should preserve event handlers', () => {
    const onClickA = vi.fn();
    const onClickB = vi.fn();
    render(_jsx(SafeClone, {
      element: _jsx("button", {
        onClick: onClickA
      }),
      props: {
        onClick: onClickB
      }
    }));
    const button = screen.getByRole('button');
    button.click();
    expect(onClickA).toHaveBeenCalled();
    expect(onClickB).toHaveBeenCalled();
  });
  it('should preserve already chained functions', () => {
    const onClickA = vi.fn();
    const onClickB = vi.fn();
    const onClickC = vi.fn();
    render(_jsx(SafeClone, {
      element: _jsx("button", {
        onClick: onClickA
      }),
      props: {
        onClick: createChainedFunction(onClickB, onClickC)
      }
    }));
    const button = screen.getByRole('button');
    button.click();
    expect(onClickA).toHaveBeenCalled();
    expect(onClickB).toHaveBeenCalled();
    expect(onClickC).toHaveBeenCalled();
  });
});