import { ComponentClass } from 'react';
declare const experimental: (...args: unknown[]) => (ComposedComponent: ComponentClass<any>) => any;
export default experimental;
export { 
/**
 * ---
 * category: utilities/react
 * ---
 * Flag React component and component props as experimental.
 * Warnings will display in the console when experimental components/props
 * props are used.
 *
 * ```js-code
 *  class Example extends Component {
 *    static propTypes = {
 *      currentProp: PropTypes.func
 *    }
 *  }
 *  export default experimental(['experimentalProp'])(Example)
 * ```
 *
 * @module experimental
 * @param {array} experimentalProps (if this argument is null or undefined, the entire component is flagged)
 * @param {string} message
 * @return {function} React component flagged as experimental
 */
experimental };
//# sourceMappingURL=experimental.d.ts.map