/**
 * ---
 * category: utilities/react
 * ---
 * Return an object with the remaining props after the given props are omitted.
 *
 * Automatically excludes the following props:
 * `theme`, `children`, `className`, `style`, `styles`, `makeStyles`,
 * `themeOverride`, `deterministicId`
 * @module omitProps
 * @param props The object to process
 * @param propsToOmit list disallowed prop keys or an object whose
 *        keys will be omitted. If not specified the automatically excluded
 *        props will be removed.
 * @param exclude an optional array of disallowed prop names to omit
 * @returns props object without the excluded props
 * @module omitProps
 */
declare function omitProps<T extends Record<string, any>>(props: T, propsToOmit?: Record<string, any> | string[], exclude?: string[]): Record<string, any>;
export default omitProps;
export { omitProps };
//# sourceMappingURL=omitProps.d.ts.map